@@ -169,8 +169,8 @@ decodePrimitive (ASN1Header Universal 0xa _ _) p   = getEnumerated p
 decodePrimitive (ASN1Header Universal 0xb _ _) _   = Left $ TypeNotImplemented "EMBEDDED PDV"
 decodePrimitive (ASN1Header Universal 0xc _ _) p   = getCharacterString UTF8 p
 decodePrimitive (ASN1Header Universal 0xd _ _) _   = Left $ TypeNotImplemented "RELATIVE-OID"
-decodePrimitive (ASN1Header Universal 0x10 _ _) _  = error "sequence not a primitive"
-decodePrimitive (ASN1Header Universal 0x11 _ _) _  = error "set not a primitive"
+decodePrimitive (ASN1Header Universal 0x10 _ _) _  = Left $ TypePrimitiveInvalid "sequence"
+decodePrimitive (ASN1Header Universal 0x11 _ _) _  = Left $ TypePrimitiveInvalid "set"
 decodePrimitive (ASN1Header Universal 0x12 _ _) p  = getCharacterString Numeric p
 decodePrimitive (ASN1Header Universal 0x13 _ _) p  = getCharacterString Printable p
 decodePrimitive (ASN1Header Universal 0x14 _ _) p  = getCharacterString T61 p
